@@ -164,12 +164,12 @@ BOOL InitApplication(HINSTANCE hInstance,int nCmdShow)
 long FAR PASCAL WndProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 {
 	int wmId, wmEvent;
-	extern soundinfo mybuffers[];
-	int i, done;
+//	extern soundinfo mybuffers[];
+//	int i, done;
 
 	switch (message) { 
 
-		case MM_WOM_DONE:
+/*		case MM_WOM_DONE:
 			if (((LPWAVEHDR) lParam)->dwFlags == WHDR_DONE | WHDR_PREPARED) {
 				i = done = 0;
 				while ((i < SOUNDBUFFERS) && (!done)) {
@@ -180,7 +180,7 @@ long FAR PASCAL WndProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 					i++;
 				}	
 			}
-			break;
+			break;*/
 
 
 		case WM_CHAR:
@@ -314,7 +314,7 @@ DlgCtrls dlgctrls[] = {
 	{ 421, FALSE, 1, "7MB RAM", "ram 7"},
 	{ 421, FALSE, 1, "8MB RAM", "ram 8"},
 
-	{ 422, TRUE, 3, "C:\\XGS", ""},
+	{ 422, TRUE, 3, "C\\XGS", ""},
 
 	{ 423, TRUE, 4, "<None>", "s5d1"},
 	{ 424, TRUE, 4, "<None>", "s5d2"},
